==> jc-1.4.0.tar.gz: java/security/spec/RSAKeyGenParameterSpec.h <==
// public class java.security.spec.RSAKeyGenParameterSpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5be0cdee4380a773 java_security_spec_RSAKeyGenParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_RSAKeyGenParameterSpec_H_
#define _JC_java_security_spec_RSAKeyGenParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$sub_refs	_jc_java_security_spec_RSAKeyGenParameterSpec$sub_refs;
typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$sub_nonrefs	_jc_java_security_spec_RSAKeyGenParameterSpec$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$refs	_jc_java_security_spec_RSAKeyGenParameterSpec$refs;
typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$nonrefs	_jc_java_security_spec_RSAKeyGenParameterSpec$nonrefs;
typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$object	_jc_java_security_spec_RSAKeyGenParameterSpec$object;

typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$fields_struct	_jc_java_security_spec_RSAKeyGenParameterSpec$fields_struct;
typedef const struct _jc_java_security_spec_RSAKeyGenParameterSpec$vmethods	_jc_java_security_spec_RSAKeyGenParameterSpec$vmethods;
typedef const struct _jc_java_security_spec_RSAKeyGenParameterSpec$vtable	_jc_java_security_spec_RSAKeyGenParameterSpec$vtable;
typedef const struct _jc_java_security_spec_RSAKeyGenParameterSpec$vtype	_jc_java_security_spec_RSAKeyGenParameterSpec$vtype;

// Class fields structure
struct _jc_java_security_spec_RSAKeyGenParameterSpec$fields_struct {
	struct _jc_java_math_BigInteger$object	*F0;
	struct _jc_java_math_BigInteger$object	*F4;
};
extern _jc_java_security_spec_RSAKeyGenParameterSpec$fields_struct _jc_java_security_spec_RSAKeyGenParameterSpec$class_fields;

// Constructors
extern void _jc_java_security_spec_RSAKeyGenParameterSpec$method$_init$94e84ad0ab39470f(_jc_env *, struct _jc_java_security_spec_RSAKeyGenParameterSpec$object *, jint, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern jint _jc_java_security_spec_RSAKeyGenParameterSpec$method$getKeysize$cf85116fb0ebb370(_jc_env *, struct _jc_java_security_spec_RSAKeyGenParameterSpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAKeyGenParameterSpec$method$getPublicExponent$6a90dc2525ab30b7(_jc_env *, struct _jc_java_security_spec_RSAKeyGenParameterSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAKeyGenParameterSpec$method_info$getKeysize$cf85116fb0ebb370;
extern _jc_method _jc_java_security_spec_RSAKeyGenParameterSpec$method_info$getPublicExponent$6a90dc2525ab30b7;

// Static methods
extern void _jc_java_security_spec_RSAKeyGenParameterSpec$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_security_spec_RSAKeyGenParameterSpec$vmethods {
	jint	(*getKeysize$cf85116fb0ebb370)(_jc_env *, struct _jc_java_security_spec_RSAKeyGenParameterSpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPublicExponent$6a90dc2525ab30b7)(_jc_env *, struct _jc_java_security_spec_RSAKeyGenParameterSpec$object *);
};

// Vtable
struct _jc_java_security_spec_RSAKeyGenParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAKeyGenParameterSpec$vmethods	java_security_spec_RSAKeyGenParameterSpec;
};

// Vtype
struct _jc_java_security_spec_RSAKeyGenParameterSpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAKeyGenParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAKeyGenParameterSpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*publicExponent;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAKeyGenParameterSpec$refs {
    _jc_java_security_spec_RSAKeyGenParameterSpec$sub_refs	java_security_spec_RSAKeyGenParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAKeyGenParameterSpec$sub_nonrefs {
	jint	keysize;
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAKeyGenParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAKeyGenParameterSpec$sub_nonrefs	java_security_spec_RSAKeyGenParameterSpec;
};

// Object instance structure
struct _jc_java_security_spec_RSAKeyGenParameterSpec$object {
	_jc_java_security_spec_RSAKeyGenParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAKeyGenParameterSpec$vtype	*vtype;
	_jc_java_security_spec_RSAKeyGenParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAKeyGenParameterSpec$vtype _jc_java_security_spec_RSAKeyGenParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAKeyGenParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAKeyGenParameterSpec$class_object;

#endif	/* _JC_java_security_spec_RSAKeyGenParameterSpec_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/RSAKeyGenParameterSpec.h <==
// public class java.security.spec.RSAKeyGenParameterSpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5be0cdee4380a773 java_security_spec_RSAKeyGenParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_RSAKeyGenParameterSpec_H_
#define _JC_java_security_spec_RSAKeyGenParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$sub_refs	_jc_java_security_spec_RSAKeyGenParameterSpec$sub_refs;
typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$sub_nonrefs	_jc_java_security_spec_RSAKeyGenParameterSpec$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$refs	_jc_java_security_spec_RSAKeyGenParameterSpec$refs;
typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$nonrefs	_jc_java_security_spec_RSAKeyGenParameterSpec$nonrefs;
typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$object	_jc_java_security_spec_RSAKeyGenParameterSpec$object;

typedef struct _jc_java_security_spec_RSAKeyGenParameterSpec$fields_struct	_jc_java_security_spec_RSAKeyGenParameterSpec$fields_struct;
typedef const struct _jc_java_security_spec_RSAKeyGenParameterSpec$vmethods	_jc_java_security_spec_RSAKeyGenParameterSpec$vmethods;
typedef const struct _jc_java_security_spec_RSAKeyGenParameterSpec$vtable	_jc_java_security_spec_RSAKeyGenParameterSpec$vtable;
typedef const struct _jc_java_security_spec_RSAKeyGenParameterSpec$vtype	_jc_java_security_spec_RSAKeyGenParameterSpec$vtype;

// Class fields structure
struct _jc_java_security_spec_RSAKeyGenParameterSpec$fields_struct {
	struct _jc_java_math_BigInteger$object	*F0;
	struct _jc_java_math_BigInteger$object	*F4;
};
extern _jc_java_security_spec_RSAKeyGenParameterSpec$fields_struct _jc_java_security_spec_RSAKeyGenParameterSpec$class_fields;

// Constructors
extern void _jc_java_security_spec_RSAKeyGenParameterSpec$method$_init$94e84ad0ab39470f(_jc_env *, struct _jc_java_security_spec_RSAKeyGenParameterSpec$object *, jint, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_security_spec_RSAKeyGenParameterSpec$method$getKeysize$cf85116fb0ebb370(_jc_env *, struct _jc_java_security_spec_RSAKeyGenParameterSpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAKeyGenParameterSpec$method$getPublicExponent$6a90dc2525ab30b7(_jc_env *, struct _jc_java_security_spec_RSAKeyGenParameterSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAKeyGenParameterSpec$method_info$getKeysize$cf85116fb0ebb370;
extern _jc_method _jc_java_security_spec_RSAKeyGenParameterSpec$method_info$getPublicExponent$6a90dc2525ab30b7;

// Static methods
extern void _jc_java_security_spec_RSAKeyGenParameterSpec$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_spec_RSAKeyGenParameterSpec$vmethods {
	jint	(*getKeysize$cf85116fb0ebb370)(_jc_env *, struct _jc_java_security_spec_RSAKeyGenParameterSpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPublicExponent$6a90dc2525ab30b7)(_jc_env *, struct _jc_java_security_spec_RSAKeyGenParameterSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_RSAKeyGenParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAKeyGenParameterSpec$vmethods	java_security_spec_RSAKeyGenParameterSpec;
};

// Vtype
struct _jc_java_security_spec_RSAKeyGenParameterSpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAKeyGenParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAKeyGenParameterSpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*publicExponent;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAKeyGenParameterSpec$refs {
    _jc_java_security_spec_RSAKeyGenParameterSpec$sub_refs	java_security_spec_RSAKeyGenParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAKeyGenParameterSpec$sub_nonrefs {
	jint	keysize;
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAKeyGenParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAKeyGenParameterSpec$sub_nonrefs	java_security_spec_RSAKeyGenParameterSpec;
};

// Object instance structure
struct _jc_java_security_spec_RSAKeyGenParameterSpec$object {
	_jc_java_security_spec_RSAKeyGenParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAKeyGenParameterSpec$vtype	*vtype;
	_jc_java_security_spec_RSAKeyGenParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAKeyGenParameterSpec$vtype _jc_java_security_spec_RSAKeyGenParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAKeyGenParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAKeyGenParameterSpec$class_object;

#endif	/* _JC_java_security_spec_RSAKeyGenParameterSpec_H_ */
